@@ -10,6 +10,7 @@
 #include <QDBusConnection>
 
 #include <KAboutData>
+#include <KCrash>
 #include <KLocalizedString>
 
 #include "../version.h"
@@ -30,6 +31,8 @@ int main(int argc, char *argv[])
     about.setDesktopFileName(QStringLiteral("org.freedesktop.impl.portal.desktop.kde"));
     KAboutData::setApplicationData(about);
 
+    KCrash::initialize();
+
     QDBusConnection sessionBus = QDBusConnection::sessionBus();
 
     if (sessionBus.registerService(QStringLiteral("org.freedesktop.impl.portal.desktop.kde"))) {
